@@ -216,7 +216,8 @@ class Field(DataVarsSerializer):
             self.element = varObj.element or \
                            self.elementByType(self.type)
             self.label = varObj.label or varObj.name
-            if not onlyhelp or varObj.syntax or self.type == "table":
+            if not onlyhelp or varObj.syntax or self.type == "table" or \
+                self.type == "bool":
                 if inbrief:
                     self.uncompatible = ""
                 else:
