@@ -27,6 +27,9 @@ from calculate.lib.utils.text import getTerminalSize
 from calculate.lib.datavars import VariableError
 from calculate.core.datavars import DataVarsCore
 from itertools import repeat
+import urllib2 as u2
+if hasattr(u2,"ssl"):
+    u2.ssl._create_default_https_context = u2.ssl._create_unverified_context
 
 from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_core3',sys.modules[__name__])
