@@ -384,7 +384,7 @@ class Display(object):
     def print_info(self, label, value):
         GREEN = TextState.Colors.GREEN
         self.display_asterisk(GREEN)
-        self._print("%s: " % label)
+        self._print(_("%s: ") % label)
         WHITE = TextState.Colors.WHITE
         self._print.foreground(WHITE)(value)
         self._print("\n")
@@ -392,7 +392,7 @@ class Display(object):
     def print_label(self, label):
         GREEN = TextState.Colors.GREEN
         self.display_asterisk(GREEN)
-        self._print("%s: " % label)
+        self._print(_("%s: ") % label)
         self._print("\n")
 
     def display_asterisk(self, color):
